@@ -23,7 +23,16 @@ class TextUtilities(object):
 
 
 def normalize_robot_name(text):
-    return text.lower().replace("_", " ")
+    return text.lower().replace("_", "").replace(" ", "")
+
+
+def is_variable_text(text):
+    from robotframework_ls.impl import robot_constants
+
+    for p in robot_constants.VARIABLE_PREFIXES:
+        if text.startswith(p + "{") and text.endswith("}"):
+            return True
+    return False
 
 
 def matches_robot_keyword(keyword_name_call_text, keyword_name, _re_cache={}):
@@ -83,10 +92,7 @@ def iter_dotted_names(text):
     splitted = text.split(".")
     splitted_len = len(splitted)
     if splitted_len > 1:
-        try:
-            import StringIO as io
-        except ImportError:
-            import io
+        import io
 
         buf = io.StringIO()
 
